package sah;

import java.util.Scanner;

public class SahovskaTabla {

	Figura[] beli=new Figura[16];
	Figura[] crni = new Figura[16]; //nakon ovoga imamo nizove sa po 16 null-ova, dakle, moraju da se kreiraju i objekti
	
	public SahovskaTabla() {
		//u konstruktoru inicijalizujemo neke pozicije
		beli[0]=new Kralj(3,0,true); // D1 -> (3,0)
		beli[1]=new Dama(0,5,true);
		beli[2]=new Top(1,6,true);
		crni[0]=new Kralj(7,7,false);
	}
	
	Figura vratiFiguruNaPoziciji(int i, int j){
		for(Figura f: beli)
			if(f!=null && f.x==i && f.y==j)
				return f;
		for(Figura f: crni)
			if(f!=null && f.x==i && f.y==j)
				return f;
		return null; //ako nismo ni kod belog ni crnog nasli nista na ovoj poziciji vracamo null
	}
	
	//ovo je method overloading - preopterecivanje metode, vidimo da gore imamo metodu sa istim nazivom samo drugacijim
	//tipovima argumenata
	Figura vratiFiguruNaPoziciji(String pozicija){
		int kolona = kolonaPozicije(pozicija);
		int red = redPozicije(pozicija);
		return vratiFiguruNaPoziciji(red, kolona); //koristimo vec prethodno gore napisani metod
	}
	
	int redPozicije(String pozicija){
		if(pozicija.length()<2)
			return -1;
		int red =pozicija.charAt(1)-'0'-1; //drugi indeks je vec zapisan isto kao karakter, 
		//npr. '5' nije isto sto i 5, da bi dobili 5, treba da uradimo '5'-'0', i jos -1 jer brojimo od 0
		return 7-red; //brojimo od donjeg kraj, tako da je izvrnuto
	}
	
	int kolonaPozicije(String pozicija){
		if(pozicija.length()<2)
			return -1;
		int kolona = pozicija.charAt(0)-'A'; //na ovaj nacin dobijamo indeks po koloni 'B'-'A' = 1, 'D'-'A'=3 itd.
		return kolona;
	}
	
	void prikazi(){
		for(int i=0; i<8; i++){
			System.out.print((8-i)+"|");
			for(int j=0; j<8; j++){
				Figura f = vratiFiguruNaPoziciji(i, j);
				if(f!=null)
					System.out.print(f.toString()+"|");
				else
					System.out.print("  |");
			}
			System.out.println();
		}
		System.out.print("  ");
		for(int i=0; i<8; i++)
			System.out.print((char)('A'+i)+" |"); //karakter 'A'+0 je 'A', 'A'+1='B' itd.. (ascii tabela)
	}
	
	boolean kraj(){
		boolean postojiKralj = false;
		for(Figura f: beli){
			if(f instanceof Kralj){
				postojiKralj = true;
				break;
			}
		}
		if(!postojiKralj){
			System.out.println("Crni je pobedio.");
			return true;
		}
		
		postojiKralj = false;
		for(Figura f: crni){
			if(f instanceof Kralj){
				postojiKralj = true;
				break;
			}
		}
		if(!postojiKralj){
			System.out.println("Beli je pobedio.");
			return true;
		}
		
		return false;
	}
	
	void startuj(){
		Scanner s=new Scanner(System.in);
		boolean igraBeli=true;
		while(true && !kraj()){
			prikazi();
			if(igraBeli)
				System.out.println("\nBeli igra: ");
			else
				System.out.println("\nCrni igra: ");
			String aktivnaPoz = s.next(); //s.next() uzima po rec
			String novaPoz = s.next();
			Figura f = vratiFiguruNaPoziciji(aktivnaPoz);
			if(f==null || f.beli!=igraBeli){ //ako tamo ne postoji figura, ili ako je odabrao figuru drugog igraca 
				System.out.println("Nedozvoljena ili nepostojeca figura.");
				continue; //prelazimo na sledecu iteraciju, i dalje ostaje da igra isti igrac dok god ne unese dozvoljen potez
			}
			int nx = redPozicije(novaPoz);
			int ny = kolonaPozicije(novaPoz);
			if(f.pomeri(nx, ny)){
				//ako je uspelo pomeranje dajemo mogucnost drugom igracu da igra
				igraBeli=!igraBeli;
			}else{
				System.out.println("Nemoguc potez.");
			}
		}
		s.close();
	}
	
	public static void main(String[] args) {
		SahovskaTabla st=new SahovskaTabla();
		st.startuj();
	}

}
